#include <Arduino.h>

#define FASTLED_ALLOW_INTERRUPTS 0
#include <FastLED.h>

#define LED_PIN       D7
#define PIR_PIN       D6

#define NUM_LEDS      60
#define NUM_LOOPS      5

#define LED_STRIP_OFF  0
#define LED_STRIP_ON   1

CRGB leds[NUM_LEDS];
int col;
int ledState;

void blink();
int getNextColour( int col );
void doLightShow( int loops );

void setup() {
  pinMode(LED_BUILTIN, OUTPUT);
  pinMode(PIR_PIN, INPUT);  

  FastLED.addLeds<WS2812, LED_PIN>(leds, NUM_LEDS);

  col = rand() % 255;
  ledState = LED_STRIP_ON;
}

void blink() {
  digitalWrite(LED_BUILTIN, HIGH); 
  delay(500);  
  digitalWrite(LED_BUILTIN, LOW); 
}

void loop() {
  int pirStat = digitalRead(PIR_PIN); 

  if (pirStat == HIGH) {  // motion detected
    doLightShow( NUM_LOOPS );
    ledState = LED_STRIP_ON;
  } 
  else {

    if( ledState == LED_STRIP_ON ) {     
      ledState = LED_STRIP_OFF;
      for (int i = 0; i <= NUM_LEDS; i++) {
        leds[i] = CHSV ( 0, 0, 0 );
        FastLED.show();
        delay(10);
      }    
    }
  }

  blink();
}

void doLightShow( int loops ) {

  while( loops-- ) {
    col = getNextColour(col);

    for (int i = 0; i <= NUM_LEDS; i++) {
      // leds[i] = CRGB ( 0, 0, 255-(offset*i));
      leds[i] = CHSV ( col, 255, 255 );
      FastLED.show();
      delay(30);
    }

    col = getNextColour(col);

    for (int i = NUM_LEDS; i >= 0; i--) {
      // leds[i] = CRGB ( 255-(offset*i), 0, 0);
      leds[i] = CHSV ( col, 255, 255 );
      FastLED.show();
      delay(30);
    }
  }
}

int getNextColour( int col ) {

  delay( 250 );

  int newCol = rand() % 255;
  while( abs(col-newCol) < 25 ) {
    newCol = rand() % 255;
  }
  return newCol;
}

